K-means clustering
******************

.. automodule:: ibmdbpy.learn.kmeans

Initiate clustering
===================

.. currentmodule:: ibmdbpy.learn.kmeans
.. highlight:: python

Create a K-means object
-----------------------

.. autoclass:: KMeans


   .. automethod:: __init__

Get parameters
--------------
.. automethod:: KMeans.get_params

Set parameters
--------------
.. automethod:: KMeans.set_params

.. rubric:: Methods

Fit and predict
===============

fit
---
.. automethod:: KMeans.fit

predict
-------
.. automethod:: KMeans.predict

fit_predict
-----------
.. automethod:: KMeans.fit_predict

Explore result
==============

describe
--------
.. automethod:: KMeans.describe

get labels
----------
.. automethod:: KMeans.labels_

_retrieve_KMeans_Model
----------------------
.. automethod:: KMeans._retrieve_KMeans_Model